@@ -159,7 +159,7 @@ impl<'a> Stream for TaskStream<'a> {
 
     fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
         if let Ok(task) = self.recver.try_recv() {
-            cx.waker().clone().wake();
+            cx.waker().wake_by_ref();
             Poll::Ready(Some(task))
         } else {
             self.tasks.set_waker(cx.waker().clone());
